@@ -1,6 +1,6 @@
 ;;; -*-emacs-lisp-*-
 
-;; Copyright (C) 2002 Free Software Foundation, Inc.
+;; Copyright (C) 2002, 2007 Free Software Foundation, Inc.
 
 (defvar generated-autoload-file)
 (defvar command-line-args-left)
@@ -14,8 +14,8 @@
 (provide 'erc-auto)
 ;;; Generated autoloads follow (made by autoload.el).
 
-;;;### (autoloads (erc-handle-irc-url erc-select erc-select-read-args)
-;;;;;;  "erc" "erc.el" (17617 33076))
+;;;### (autoloads (erc-handle-irc-url erc erc-select-read-args) "erc"
+;;;;;;  "erc.el" (17935 2700))
 ;;; Generated autoloads from erc.el
 
 (autoload (quote erc-select-read-args) "erc" "\
@@ -23,9 +23,13 @@ Prompt the user for values of nick, server, port, and password.
 
 \(fn)" nil nil)
 
-(autoload (quote erc-select) "erc" "\
-Select connection parameters and run ERC.
-Non-interactively, it takes keyword arguments
+(autoload (quote erc) "erc" "\
+ERC is a powerful, modular, and extensible IRC client.
+This function is the main entry point for ERC.
+
+It permits you to select connection parameters, and then starts ERC.
+
+Non-interactively, it takes the keyword arguments
    (server (erc-compute-server))
    (port   (erc-compute-port))
    (nick   (erc-compute-nick))
@@ -34,14 +38,16 @@ Non-interactively, it takes keyword arguments
 
 That is, if called with
 
-   (erc-select :server \"irc.freenode.net\" :full-name \"Harry S Truman\")
+   (erc :server \"irc.freenode.net\" :full-name \"Harry S Truman\")
 
-server and full-name will be set to those values, whereas
+then the server and full-name will be set to those values, whereas
 `erc-compute-port', `erc-compute-nick' and `erc-compute-full-name' will
 be invoked for the values of the other parameters.
 
 \(fn &key (SERVER (erc-compute-server)) (PORT (erc-compute-port)) (NICK (erc-compute-nick)) PASSWORD (FULL-NAME (erc-compute-full-name)))" t nil)
 
+(defalias (quote erc-select) (quote erc))
+
 (autoload (quote erc-handle-irc-url) "erc" "\
 Use ERC to IRC on HOST:PORT in CHANNEL as USER with PASSWORD.
 If ERC is already connected to HOST:PORT, simply /join CHANNEL.
@@ -51,26 +57,26 @@ Otherwise, connect to HOST:PORT as USER and /join CHANNEL.
 
 ;;;***
 
-;;;### (autoloads nil "erc-autojoin" "erc-autojoin.el" (17589 25127))
-;;; Generated autoloads from erc-autojoin.el
- (autoload 'erc-autojoin-mode "erc-autojoin" nil t)
-
-;;;***
-
-;;;### (autoloads nil "erc-bbdb" "erc-bbdb.el" (17589 25128))
+;;;### (autoloads nil "erc-bbdb" "erc-bbdb.el" (17933 57358))
 ;;; Generated autoloads from erc-bbdb.el
  (autoload 'erc-bbdb-mode "erc-bbdb")
 
 ;;;***
 
-;;;### (autoloads nil "erc-button" "erc-button.el" (17589 25128))
+;;;### (autoloads nil "erc-button" "erc-button.el" (17895 40324))
 ;;; Generated autoloads from erc-button.el
  (autoload 'erc-button-mode "erc-button" nil t)
 
+;;;***
+
+;;;### (autoloads nil "erc-capab" "erc-capab.el" (17914 1875))
+;;; Generated autoloads from erc-capab.el
+ (autoload 'erc-capab-identify-mode "erc-capab" nil t)
+
 ;;;***
 
 ;;;### (autoloads (erc-chess-ctcp-query-handler erc-cmd-CHESS) "erc-chess"
-;;;;;;  "erc-chess.el" (17589 25128))
+;;;;;;  "erc-chess.el" (17935 578))
 ;;; Generated autoloads from erc-chess.el
 
 (defvar erc-ctcp-query-CHESS-hook (quote (erc-chess-ctcp-query-handler)))
@@ -88,27 +94,14 @@ Not documented
 
 ;;;***
 
-;;;### (autoloads nil "erc-compat" "erc-compat.el" (17589 25128))
+;;;### (autoloads nil "erc-compat" "erc-compat.el" (17850 33506))
 ;;; Generated autoloads from erc-compat.el
  (autoload 'erc-define-minor-mode "erc-compat")
 
-;;;***
-
-;;;### (autoloads (erc-complete) "erc-complete" "erc-complete.el"
-;;;;;;  (17589 25128))
-;;; Generated autoloads from erc-complete.el
-
-(autoload (quote erc-complete) "erc-complete" "\
-Complete nick at point.
-See `erc-try-complete-nick' for more technical info.
-This function is obsolete, use `erc-pcomplete' instead.
-
-\(fn)" t nil)
-
 ;;;***
 
 ;;;### (autoloads (erc-ctcp-query-DCC pcomplete/erc-mode/DCC erc-cmd-DCC)
-;;;;;;  "erc-dcc" "erc-dcc.el" (17589 25128))
+;;;;;;  "erc-dcc" "erc-dcc.el" (17850 33506))
 ;;; Generated autoloads from erc-dcc.el
 
 (autoload (quote erc-cmd-DCC) "erc-dcc" "\
@@ -140,7 +133,7 @@ that subcommand.
 ;;;;;;  erc-ezb-add-session erc-ezb-end-of-session-list erc-ezb-init-session-list
 ;;;;;;  erc-ezb-identify erc-ezb-notice-autodetect erc-ezb-lookup-action
 ;;;;;;  erc-ezb-get-login erc-cmd-ezb) "erc-ezbounce" "erc-ezbounce.el"
-;;;;;;  (17589 25128))
+;;;;;;  (17850 33506))
 ;;; Generated autoloads from erc-ezbounce.el
 
 (autoload (quote erc-cmd-ezb) "erc-ezbounce" "\
@@ -171,7 +164,7 @@ Identify to the EZBouncer server.
 \(fn MESSAGE)" nil nil)
 
 (autoload (quote erc-ezb-init-session-list) "erc-ezbounce" "\
-Reset the EZBounce session list to NIL.
+Reset the EZBounce session list to nil.
 
 \(fn MESSAGE)" nil nil)
 
@@ -202,7 +195,7 @@ Add EZBouncer convenience functions to ERC.
 
 ;;;***
 
-;;;### (autoloads (erc-fill) "erc-fill" "erc-fill.el" (17589 25128))
+;;;### (autoloads (erc-fill) "erc-fill" "erc-fill.el" (17850 33703))
 ;;; Generated autoloads from erc-fill.el
  (autoload 'erc-fill-mode "erc-fill" nil t)
 
@@ -212,10 +205,17 @@ You can put this on `erc-insert-modify-hook' and/or `erc-send-modify-hook'.
 
 \(fn)" nil nil)
 
+;;;***
+
+;;;### (autoloads nil "erc-hecomplete" "erc-hecomplete.el" (17850
+;;;;;;  33506))
+;;; Generated autoloads from erc-hecomplete.el
+ (autoload 'erc-hecomplete-mode "erc-hecomplete" nil t)
+
 ;;;***
 
 ;;;### (autoloads (erc-identd-stop erc-identd-start) "erc-identd"
-;;;;;;  "erc-identd.el" (17589 25128))
+;;;;;;  "erc-identd.el" (17850 33506))
 ;;; Generated autoloads from erc-identd.el
  (autoload 'erc-identd-mode "erc-identd")
 
@@ -237,7 +237,7 @@ Not documented
 ;;;***
 
 ;;;### (autoloads (erc-create-imenu-index) "erc-imenu" "erc-imenu.el"
-;;;;;;  (17589 25128))
+;;;;;;  (17850 33506))
 ;;; Generated autoloads from erc-imenu.el
 
 (autoload (quote erc-create-imenu-index) "erc-imenu" "\
@@ -245,10 +245,16 @@ Not documented
 
 \(fn)" nil nil)
 
+;;;***
+
+;;;### (autoloads nil "erc-join" "erc-join.el" (17850 33506))
+;;; Generated autoloads from erc-join.el
+ (autoload 'erc-autojoin-mode "erc-join" nil t)
+
 ;;;***
 
 ;;;### (autoloads (erc-chanlist erc-list-channels) "erc-list" "erc-list.el"
-;;;;;;  (17589 25128))
+;;;;;;  (17935 1158))
 ;;; Generated autoloads from erc-list.el
  (autoload 'erc-list-mode "erc-list")
 
@@ -269,7 +275,7 @@ to RFC and send the LIST header (#321) at start of list transmission.
 ;;;***
 
 ;;;### (autoloads (erc-save-buffer-in-logs erc-logging-enabled) "erc-log"
-;;;;;;  "erc-log.el" (17617 33076))
+;;;;;;  "erc-log.el" (17932 26802))
 ;;; Generated autoloads from erc-log.el
  (autoload 'erc-log-mode "erc-log" nil t)
 
@@ -300,8 +306,8 @@ You can save every individual message by putting this function on
 
 ;;;### (autoloads (erc-delete-dangerous-host erc-add-dangerous-host
 ;;;;;;  erc-delete-keyword erc-add-keyword erc-delete-fool erc-add-fool
-;;;;;;  erc-delete-pal erc-add-pal) "erc-match" "erc-match.el" (17613
-;;;;;;  7074))
+;;;;;;  erc-delete-pal erc-add-pal) "erc-match" "erc-match.el" (17850
+;;;;;;  33744))
 ;;; Generated autoloads from erc-match.el
  (autoload 'erc-match-mode "erc-match")
 
@@ -347,26 +353,14 @@ Delete dangerous-host interactively to `erc-dangerous-hosts'.
 
 ;;;***
 
-;;;### (autoloads (erc-server-select erc-determine-network) "erc-nets"
-;;;;;;  "erc-nets.el" (17589 25128))
-;;; Generated autoloads from erc-nets.el
-
-(autoload (quote erc-determine-network) "erc-nets" "\
-Return the name of the network or \"Unknown\" as a symbol.  Use the
-server parameter NETWORK if provided, otherwise parse the server name and
-search for a match in `erc-networks-alist'.
-
-\(fn)" nil nil)
-
-(autoload (quote erc-server-select) "erc-nets" "\
-Interactively select a server to connect to using `erc-server-alist'.
-
-\(fn)" t nil)
+;;;### (autoloads nil "erc-menu" "erc-menu.el" (17870 3612))
+;;; Generated autoloads from erc-menu.el
+ (autoload 'erc-menu-mode "erc-menu" nil t)
 
 ;;;***
 
 ;;;### (autoloads (erc-cmd-WHOLEFT) "erc-netsplit" "erc-netsplit.el"
-;;;;;;  (17589 25128))
+;;;;;;  (17850 33506))
 ;;; Generated autoloads from erc-netsplit.el
  (autoload 'erc-netsplit-mode "erc-netsplit")
 
@@ -377,26 +371,26 @@ Show who's gone.
 
 ;;;***
 
-;;;### (autoloads (erc-nickserv-identify erc-nickserv-identify-mode)
-;;;;;;  "erc-nickserv" "erc-nickserv.el" (17589 25128))
-;;; Generated autoloads from erc-nickserv.el
- (autoload 'erc-services-mode "erc-nickserv" nil t)
+;;;### (autoloads (erc-server-select erc-determine-network) "erc-networks"
+;;;;;;  "erc-networks.el" (17850 33506))
+;;; Generated autoloads from erc-networks.el
 
-(autoload (quote erc-nickserv-identify-mode) "erc-nickserv" "\
-Set up hooks according to which MODE the user has chosen.
+(autoload (quote erc-determine-network) "erc-networks" "\
+Return the name of the network or \"Unknown\" as a symbol.  Use the
+server parameter NETWORK if provided, otherwise parse the server name and
+search for a match in `erc-networks-alist'.
 
-\(fn MODE)" t nil)
+\(fn)" nil nil)
 
-(autoload (quote erc-nickserv-identify) "erc-nickserv" "\
-Send an \"identify <PASSWORD>\" message to NickServ.
-When called interactively, read the password using `read-passwd'.
+(autoload (quote erc-server-select) "erc-networks" "\
+Interactively select a server to connect to using `erc-server-alist'.
 
-\(fn PASSWORD)" t nil)
+\(fn)" t nil)
 
 ;;;***
 
 ;;;### (autoloads (pcomplete/erc-mode/NOTIFY erc-cmd-NOTIFY) "erc-notify"
-;;;;;;  "erc-notify.el" (17589 25128))
+;;;;;;  "erc-notify.el" (17850 33506))
 ;;; Generated autoloads from erc-notify.el
  (autoload 'erc-notify-mode "erc-notify" nil t)
 
@@ -414,38 +408,56 @@ Not documented
 
 ;;;***
 
-;;;### (autoloads nil "erc-page" "erc-page.el" (17589 25128))
+;;;### (autoloads nil "erc-page" "erc-page.el" (17850 33506))
 ;;; Generated autoloads from erc-page.el
  (autoload 'erc-page-mode "erc-page")
 
 ;;;***
 
-;;;### (autoloads nil "erc-pcomplete" "erc-pcomplete.el" (17589 25128))
+;;;### (autoloads nil "erc-pcomplete" "erc-pcomplete.el" (17850 33506))
 ;;; Generated autoloads from erc-pcomplete.el
  (autoload 'erc-completion-mode "erc-pcomplete" nil t)
 
 ;;;***
 
-;;;### (autoloads nil "erc-replace" "erc-replace.el" (17589 25128))
+;;;### (autoloads nil "erc-replace" "erc-replace.el" (17850 33506))
 ;;; Generated autoloads from erc-replace.el
  (autoload 'erc-replace-mode "erc-replace")
 
 ;;;***
 
-;;;### (autoloads nil "erc-ring" "erc-ring.el" (17589 25128))
+;;;### (autoloads nil "erc-ring" "erc-ring.el" (17850 33795))
 ;;; Generated autoloads from erc-ring.el
  (autoload 'erc-ring-mode "erc-ring" nil t)
 
 ;;;***
 
-;;;### (autoloads nil "erc-sound" "erc-sound.el" (17589 25128))
+;;;### (autoloads (erc-nickserv-identify erc-nickserv-identify-mode)
+;;;;;;  "erc-services" "erc-services.el" (17850 33506))
+;;; Generated autoloads from erc-services.el
+ (autoload 'erc-services-mode "erc-services" nil t)
+
+(autoload (quote erc-nickserv-identify-mode) "erc-services" "\
+Set up hooks according to which MODE the user has chosen.
+
+\(fn MODE)" t nil)
+
+(autoload (quote erc-nickserv-identify) "erc-services" "\
+Send an \"identify <PASSWORD>\" message to NickServ.
+When called interactively, read the password using `read-passwd'.
+
+\(fn PASSWORD)" t nil)
+
+;;;***
+
+;;;### (autoloads nil "erc-sound" "erc-sound.el" (17850 33506))
 ;;; Generated autoloads from erc-sound.el
  (autoload 'erc-sound-mode "erc-sound")
 
 ;;;***
 
 ;;;### (autoloads (erc-speedbar-browser) "erc-speedbar" "erc-speedbar.el"
-;;;;;;  (17589 25128))
+;;;;;;  (17850 33814))
 ;;; Generated autoloads from erc-speedbar.el
 
 (autoload (quote erc-speedbar-browser) "erc-speedbar" "\
@@ -456,27 +468,43 @@ This will add a speedbar major display mode.
 
 ;;;***
 
-;;;### (autoloads nil "erc-spelling" "erc-spelling.el" (17617 33076))
+;;;### (autoloads nil "erc-spelling" "erc-spelling.el" (17850 33506))
 ;;; Generated autoloads from erc-spelling.el
  (autoload 'erc-spelling-mode "erc-spelling" nil t)
 
 ;;;***
 
-;;;### (autoloads nil "erc-stamp" "erc-stamp.el" (17589 25128))
+;;;### (autoloads nil "erc-stamp" "erc-stamp.el" (17850 33506))
 ;;; Generated autoloads from erc-stamp.el
  (autoload 'erc-timestamp-mode "erc-stamp" nil t)
 
 ;;;***
 
-;;;### (autoloads nil "erc-track" "erc-track.el" (17589 25128))
+;;;### (autoloads (erc-track-minor-mode) "erc-track" "erc-track.el"
+;;;;;;  (17932 32807))
 ;;; Generated autoloads from erc-track.el
+
+(defvar erc-track-minor-mode nil "\
+Non-nil if Erc-Track minor mode is enabled.
+See the command `erc-track-minor-mode' for a description of this minor-mode.")
+
+(custom-autoload (quote erc-track-minor-mode) "erc-track" nil)
+
+(autoload (quote erc-track-minor-mode) "erc-track" "\
+Global minor mode for tracking ERC buffers and showing activity in the
+mode line.
+
+This exists for the sole purpose of providing the C-c C-SPC and
+C-c C-@ keybindings.  Make sure that you have enabled the track
+module, otherwise the keybindings will not do anything useful.
+
+\(fn &optional ARG)" t nil)
  (autoload 'erc-track-mode "erc-track" nil t)
- (autoload 'erc-track-when-inactive-mode "erc-track" nil t)
 
 ;;;***
 
 ;;;### (autoloads (erc-truncate-buffer erc-truncate-buffer-to-size)
-;;;;;;  "erc-truncate" "erc-truncate.el" (17589 25128))
+;;;;;;  "erc-truncate" "erc-truncate.el" (17850 33506))
 ;;; Generated autoloads from erc-truncate.el
  (autoload 'erc-truncate-mode "erc-truncate" nil t)
 
@@ -495,8 +523,8 @@ Meant to be used in hooks, like `erc-insert-post-hook'.
 
 ;;;***
 
-;;;### (autoloads (erc-xdcc-add-file) "erc-xdcc" "erc-xdcc.el" (17589
-;;;;;;  25128))
+;;;### (autoloads (erc-xdcc-add-file) "erc-xdcc" "erc-xdcc.el" (17850
+;;;;;;  33506))
 ;;; Generated autoloads from erc-xdcc.el
 
 (autoload (quote erc-xdcc-add-file) "erc-xdcc" "\
@@ -507,12 +535,12 @@ Add a file to `erc-xdcc-files'.
 ;;;***
 
 ;;;### (autoloads nil nil ("erc-backend.el" "erc-goodies.el" "erc-ibuffer.el"
-;;;;;;  "erc-lang.el" "erc-maint.el" "erc-menu.el" "erc-nicklist.el"
-;;;;;;  "erc-speak.el" "erc-viper.el") (17617 33344 333566))
+;;;;;;  "erc-lang.el" "erc-maint.el" "erc-nicklist.el" "erc-speak.el"
+;;;;;;  "erc-viper.el") (17935 2854 224794))
 
 ;;;***
 
-;;;### (autoloads nil "erc-autoaway" "erc-autoaway.el" (17589 25127))
+;;;### (autoloads nil "erc-autoaway" "erc-autoaway.el" (17932 31395))
 ;;; Generated autoloads from erc-autoaway.el
  (autoload 'erc-autoaway-mode "erc-autoaway")
 
